@@ -9,9 +9,9 @@ import os
 import re
 from typing import Dict, List, Optional, Tuple
 
-import helpers.datetime_ as hdt
-import helpers.dbg as dbg
-import helpers.system_interaction as si
+import p1_data_client_python.helpers.datetime_ as hdt
+import p1_data_client_python.helpers.dbg as dbg
+import p1_data_client_python.helpers.system_interaction as si
 
 _LOG = logging.getLogger(__name__)
 
